@@ -7,10 +7,7 @@ def add_contact(name, address, step, **kwargs):
     redis_client = kwargs.get('redis_client')
     executor =  kwargs.get('executor')
     providers = kwargs.get("providers")
-    rpc_url = providers['ethereum']['rpc']
-    provider = Web3.HTTPProvider(rpc_url)
-    provider.middlewares.clear()
-    w3 = Web3(provider)
+    w3 = providers['ethereum']['w3']
     ens_name = None
     try:
         ns = ENS.from_web3(w3)
