@@ -225,18 +225,16 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
         "base": {
             "rpc": configs.base_rpc_url,
             "scan": configs.base_scan_url,
+            "w3": Web3(Web3.HTTPProvider(configs.base_rpc_url))
         }, 
         "ethereum": {
-            "rpc": configs.eth_rpc_url,
-            "scan": configs.eth_scan_url
+            ...
         },
         "eth": {
-            "rpc": configs.eth_rpc_url,
-            "scan": configs.eth_scan_url
+            ...
         },
         "bsc": {
-            "rpc": configs.bsc_rpc_url,
-            "scan": configs.bsc_scan_url
+            ...
         },
       },
     """
@@ -254,12 +252,10 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
     if not providers or chain_raw not in providers:
         raise ValueError(f"Provider for chain {chain} not found")
     
-    rpc_url = providers[chain_raw]['rpc']
     blockchain_explore = providers[chain_raw]['scan']
 
-    provider = Web3.HTTPProvider(rpc_url)
-    provider.middlewares.clear()
-    w3 = Web3(provider)
+    w3 = providers[chain_raw]['w3']
+    eth_w3 = providers['eth']['w3']
     token_raw = token
     token = w3.to_checksum_address(token_mapping[chain_raw][token_raw.lower()])
 
@@ -282,7 +278,7 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
           action_data = ActionData(func='', group='', params=action_params)
           action = Action(msg=None, type='wallet', data=action_data.__dict__)
 
-          code, res = get_contact_address(redis_client, executor, receiver, w3)
+          code, res = get_contact_address(redis_client, executor, receiver, eth_w3)
           if code != 200:
               info = {"content": f"Cannot find {receiver} on contact", "code": 420}
               return {
@@ -307,7 +303,7 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
             'action': action.__dict__,
             'next_action': next_action.__dict__
           }
-      code, res = get_contact_address(redis_client, executor, receiver, w3)
+      code, res = get_contact_address(redis_client, executor, receiver, eth_w3)
       if code != 200:
           info = {"content": f"Cannot find {receiver} on contact", "code": 420}
           return {
@@ -379,13 +375,12 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
         active_chain = "base"
       if active_chain.lower() != chain_raw:
           params = {
-            "func": "wallet_switchEthereumChain",
             "chainId": chain_id_mapping[chain_raw]
           }
-          action_data = ActionData(func='', group='', params=params)
+          action_data = ActionData(func='switch_chain', group='', params=params)
           action = Action(msg=None, type='setting', data=action_data.__dict__)
 
-          code, res = get_contact_address(redis_client, executor, receiver, w3)
+          code, res = get_contact_address(redis_client, executor, receiver, eth_w3)
           if code != 200:
               info = {"content": f"Cannot find {receiver} on contact", "code": 420}
               return {
@@ -412,7 +407,7 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
             'next_action': next_action.__dict__
           }
       else:
-          code, res = get_contact_address(redis_client, executor, receiver, w3)
+          code, res = get_contact_address(redis_client, executor, receiver, eth_w3)
           if code != 200:
               info = {"content": f"Cannot find {receiver} on contact", "code": 420}
               return {
