@@ -18,13 +18,20 @@ def redis_add_contact(redis_client, user, name, address, ens_name = None) -> Tup
     })
     return 200, f"Added {name}({address}) to contacts successfully"
 
-def get_contact_address(redis_client, user, contact, w3):
+def get_contact_address(redis_client, user, contact, w3: Web3):
     if not Web3.is_address(contact):
         name = contact
         key = user + '_' + name
         lower_key = key.lower()
         to = redis_client.hget(f"contact:{lower_key}","address")
         if not to:
+            if name.endswith(".eth"):
+                try:
+                    to = w3.ens.address(name)
+                    if not to:
+                        return 404, f"Cannot find {name} on ENS"
+                except Exception as e:
+                    return 500, e
             return 404, f"Cannot find {name} on contact"
     else:
         to = contact
